try_init

Function try_init 

pub fn try_init(config: Config) -> Result<(), SetLoggerError>
Attempt to initialize the logger with the given config.

Errors

This function will fail if it is called more than once, or if another library has already initialized a global logger.